@@ -19,3 +19,14 @@ pub static X64_PE_PARAM_REGS: &[iced_x86::Register] = &[
     iced_x86::Register::R8,
     iced_x86::Register::R9,
 ];
+
+/// x64 Mach-O argument registers
+#[rustfmt::skip]
+pub static X64_MACHO_PARAM_REGS: &[iced_x86::Register] = &[
+    iced_x86::Register::RDI,
+    iced_x86::Register::RSI,
+    iced_x86::Register::RDX,
+    iced_x86::Register::RCX,
+    iced_x86::Register::R8,
+    iced_x86::Register::R9,
+];
